@@ -12,6 +12,7 @@ from .common_issues_check import CommonIssuesCheck
 from .configuration_check import ConfigurationCheck
 from .filesystem_check import FilesystemCheck
 from .installation_check import InstallationCheck
+from .instructions_check import InstructionsCheck
 from .mcp_check import MCPCheck
 from .monitor_check import MonitorCheck
 from .startup_log_check import StartupLogCheck
@@ -24,6 +25,7 @@ __all__ = [
     "ConfigurationCheck",
     "FilesystemCheck",
     "InstallationCheck",
+    "InstructionsCheck",
     "MCPCheck",
     "MonitorCheck",
     "StartupLogCheck",
